/********************************************************************************
** Form generated from reading UI file 'lightPollutionWidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LIGHTPOLLUTIONWIDGET_H
#define UI_LIGHTPOLLUTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "LogarithmicSpinBox.hpp"

QT_BEGIN_NAMESPACE

class Ui_lightPollutionWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QComboBox *modeCB;
    QSpacerItem *horizontalSpacer;
    QSlider *manualSlider;
    QDoubleSpinBox *fromSQMmag_SB;
    LogarithmicSpinBox *fromSQMcdm2_logSB;
    QComboBox *unitCB;

    void setupUi(QWidget *lightPollutionWidget)
    {
        if (lightPollutionWidget->objectName().isEmpty())
            lightPollutionWidget->setObjectName("lightPollutionWidget");
        lightPollutionWidget->resize(536, 34);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lightPollutionWidget->sizePolicy().hasHeightForWidth());
        lightPollutionWidget->setSizePolicy(sizePolicy);
        lightPollutionWidget->setWindowTitle(QString::fromUtf8("Form"));
        horizontalLayout = new QHBoxLayout(lightPollutionWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        modeCB = new QComboBox(lightPollutionWidget);
        modeCB->addItem(QString());
        modeCB->addItem(QString());
        modeCB->addItem(QString());
        modeCB->setObjectName("modeCB");

        horizontalLayout->addWidget(modeCB);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        manualSlider = new QSlider(lightPollutionWidget);
        manualSlider->setObjectName("manualSlider");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(manualSlider->sizePolicy().hasHeightForWidth());
        manualSlider->setSizePolicy(sizePolicy1);
        manualSlider->setMinimum(-999999999);
        manualSlider->setMaximum(0);
        manualSlider->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(manualSlider);

        fromSQMmag_SB = new QDoubleSpinBox(lightPollutionWidget);
        fromSQMmag_SB->setObjectName("fromSQMmag_SB");
        fromSQMmag_SB->setDecimals(2);
        fromSQMmag_SB->setMaximum(0.990000000000000);
        fromSQMmag_SB->setSingleStep(0.100000000000000);

        horizontalLayout->addWidget(fromSQMmag_SB);

        fromSQMcdm2_logSB = new LogarithmicSpinBox(lightPollutionWidget);
        fromSQMcdm2_logSB->setObjectName("fromSQMcdm2_logSB");

        horizontalLayout->addWidget(fromSQMcdm2_logSB);

        unitCB = new QComboBox(lightPollutionWidget);
        unitCB->addItem(QString());
        unitCB->addItem(QString());
        unitCB->addItem(QString());
        unitCB->addItem(QString());
        unitCB->setObjectName("unitCB");

        horizontalLayout->addWidget(unitCB);


        retranslateUi(lightPollutionWidget);

        QMetaObject::connectSlotsByName(lightPollutionWidget);
    } // setupUi

    void retranslateUi(QWidget *lightPollutionWidget)
    {
        modeCB->setItemText(0, QCoreApplication::translate("lightPollutionWidget", "automatic from locations database", nullptr));
        modeCB->setItemText(1, QCoreApplication::translate("lightPollutionWidget", "manual", nullptr));
        modeCB->setItemText(2, QCoreApplication::translate("lightPollutionWidget", "manual from SQM", nullptr));

        unitCB->setItemText(0, QCoreApplication::translate("lightPollutionWidget", "cd/m\302\262", nullptr));
        unitCB->setItemText(1, QCoreApplication::translate("lightPollutionWidget", "mcd/m\302\262", nullptr));
        unitCB->setItemText(2, QCoreApplication::translate("lightPollutionWidget", "\316\274cd/m\302\262", nullptr));
        unitCB->setItemText(3, QCoreApplication::translate("lightPollutionWidget", "mag/arcsec\302\262", nullptr));

        unitCB->setCurrentText(QCoreApplication::translate("lightPollutionWidget", "cd/m\302\262", nullptr));
        (void)lightPollutionWidget;
    } // retranslateUi

};

namespace Ui {
    class lightPollutionWidget: public Ui_lightPollutionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LIGHTPOLLUTIONWIDGET_H
